@@ -17,13 +17,13 @@
 class MirrorCommand : public UndoCommand
 {
 public:
-    MirrorCommand(bool horizonal, bool vertical);
+    MirrorCommand(bool horizontal, bool vertical);
     ~MirrorCommand() override = default;
 
     virtual QImage redo(QImage image) override;
 
     virtual QImage undo(QImage image) override;
-    
+
 private:
     bool m_horizontal;
     bool m_vertical;
