@@ -13,10 +13,11 @@ class KQuickImageEditorPlugin : public QQmlExtensionPlugin
     Q_PLUGIN_METADATA(IID QQmlExtensionInterface_iid)
 public:
     void registerTypes(const char *uri) override;
+
 private:
     QString resolveFilePath(const QString &path) const
     {
-#if defined(Q_OS_ANDROID) && QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
+#if defined(Q_OS_ANDROID)
         return QStringLiteral(":/android_rcc_bundle/qml/org/kde/kquickimageeditor/") + path;
 #else
         return baseUrl().toLocalFile() + QLatin1Char('/') + path;
@@ -24,7 +25,7 @@ private:
     }
     QString resolveFileUrl(const QString &filePath) const
     {
-#if defined(Q_OS_ANDROID) && QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
+#if defined(Q_OS_ANDROID)
         return QStringLiteral("qrc:/android_rcc_bundle/qml/org/kde/kquickimageeditor/") + filePath;
 #else
         return baseUrl().toString() + QLatin1Char('/') + filePath;
